import 'package:contentsquare/contentsquare.dart';
import 'package:contentsquare_webview_flutter/src/kirk_douglas.dart';
import 'package:flutter/widgets.dart';
import 'package:webview_flutter/webview_flutter.dart';

/// Widget used to easily track a WebView from webview_flutter package.
///
/// **Important**: Widgets created between [ContentsquareWebViewFlutterTrackerBuilder]
/// and [WebViewWidget] will **not** be tracked:
///   - They will not be selectable in the zoning analysis.
///   - Gestures on those widgets will not be tracked.
/// Therefore you should always use [ContentsquareWebViewFlutterTrackerBuilder] as
/// close to the [WebViewWidget] as possible.
class ContentsquareWebViewFlutterTrackerBuilder extends StatelessWidget {
  /// Creates a widget which provides a tracker to track a WebView from
  /// webview_flutter package
  ///
  /// For the tracking to work, you need to specify the following:
  ///  - The [webViewController] of the WebView
  ///  - The [onTrackingReady] callback which will be called when the tracking
  ///  is ready.
  ///  Warning : You should call the [webViewController.loadRequest] in this
  ///  callback to make sure the tracker is initialized before the page is displayed
  ///  - The [child] widget to display
  ///
  /// Example:
  /// ```dart
  /// ContentsquareWebViewFlutterTrackerBuilder(
  ///   webViewController: webViewController,
  ///   onTrackingReady: () {
  ///     webViewController.loadRequest(Uri.parse('your_tracked_website.com'));
  ///   },
  ///   child: WebViewWidget(controller: webViewController),
  /// )
  /// ```
  const ContentsquareWebViewFlutterTrackerBuilder({
    Key? key,
    required this.webViewController,
    required this.onTrackingReady,
    required this.child,
  }) : super(key: key);

  /// The controller of the WebView.
  final WebViewController webViewController;

  /// The child widget to display.
  final Widget child;

  /// A callback executed when tracking initialization is done.
  ///
  /// Typically, you would call [WebViewController.loadRequest] in this callback.
  ///
  /// Example:
  /// ```dart
  /// ContentsquareWebViewFlutterTrackerBuilder(
  ///   ...
  ///   onTrackingReady: () {
  ///     webViewController.loadRequest(Uri.parse('your_tracked_website.com'));
  ///   },
  /// )
  /// ```
  final VoidCallback onTrackingReady;

  @override
  Widget build(BuildContext context) {
    return ContentsquareWebViewTrackerBuilder(
      builder: (context, tracker) {
        return colin_firth(
          jason_robards: tracker,
          sean_connery: webViewController,
          mel_gibson: onTrackingReady,
          henry_fonda: child,
        );
      },
    );
  }
}
